<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fa">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>فیلتر:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>انتخاب فونت ترمینال</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>فونت:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>اندازه:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>پیش نمایش</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Bookmarks</source>
        <translation>نشانک ها</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="216"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>برای مشاهده ترمینال کلید %1 را فشار دهید.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>&amp;Next Tab</source>
        <translation>&amp;زبانه بعدی</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>&amp;Previous Tab</source>
        <translation>زبانه &amp;قبلی</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="274"/>
        <source>Move Tab &amp;Left</source>
        <translation>انتقال زبانه به &amp;چپ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>Move Tab &amp;Right</source>
        <translation>انتقال زبانه به &amp;راست</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="255"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>&amp;پاک کردن ترمینال فعال</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="197"/>
        <source>Keep window open when it loses focus</source>
        <translation>پنجره در صورت از دست دادن فوکوس باز نگه داشته شود</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>&amp;Previous Tab in History</source>
        <translation>زبانه ی &amp;قبلی در تاریخچه</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="271"/>
        <source>&amp;Next Tab in History</source>
        <translation>زبانه ی &amp;بعدی در تاریخچه</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>Tab</source>
        <translation>زبانه</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>Go to</source>
        <translation>برو به</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>Split &amp;View Top-Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <source>Split Vie&amp;w Left-Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>&amp;Close Subterminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>&amp;Top Subterminal</source>
        <translation>زیرترمینال &amp;بالا</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="310"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>زیرترمینال &amp;پایین</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="313"/>
        <source>L&amp;eft Subterminal</source>
        <translation>زیرترمینال &amp;چپ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="316"/>
        <source>R&amp;ight Subterminal</source>
        <translation>زیر ترمینال &amp;راست</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>Copy &amp;Selection</source>
        <translation>کپی &amp;انتخاب شده</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Paste Clip&amp;board</source>
        <translation>چسباندن از &amp;حافظه</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="329"/>
        <source>Paste S&amp;election</source>
        <translation>&amp;چسباندن انتخاب شده</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="332"/>
        <source>Zoom &amp;in</source>
        <translation>&amp;یزرگنمایی</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="335"/>
        <source>Zoom &amp;out</source>
        <translation>&amp;کوچکنمایی</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="338"/>
        <source>Zoom rese&amp;t</source>
        <translation>&amp;بازنشانی بزرگنمایی</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>&amp;Find...</source>
        <translation>&amp;جستجو...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="346"/>
        <source>Handle history...</source>
        <translation>مدیریت تاریخچه...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="354"/>
        <source>&amp;Save Session</source>
        <translation>&amp;ذخیره جلسه کاری</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>&amp;Load Session</source>
        <translation>&amp;فراخوانی جلسه کاری</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>&amp;Toggle Menu</source>
        <translation>&amp;تغییر وضعیت نمایش منو</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>Rename session</source>
        <translation>تغییر نام جلسه کاری</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>&amp;New Tab</source>
        <translation>&amp;زبانه جدید</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <source>New Tab From &amp;Preset</source>
        <translation>زبانه جدید از &amp;چیدمان</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="386"/>
        <source>1 &amp;Terminal</source>
        <translation>۱ &amp;ترمینال</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>۲ ترمینال &amp;افقی</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>۲ ترمینال &amp;عمودی</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="394"/>
        <source>4 Terminal&amp;s</source>
        <translation>&amp;۴ ترمینال</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="400"/>
        <source>&amp;Close Tab</source>
        <translation>&amp;بستن زبانه</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="403"/>
        <source>&amp;New Window</source>
        <translation>&amp;پنجره جدید</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="408"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;تنظیمات...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="412"/>
        <source>&amp;Quit</source>
        <translation>&amp;خروج</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;مخفی کردن قاب پنجره</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>&amp;Show Tab Bar</source>
        <translation>&amp;نمایش نوار زبانه ها</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="444"/>
        <source>Fullscreen</source>
        <translation>تمام صفحه</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="450"/>
        <source>Toggle Bookmarks</source>
        <translation>تغییر وضعیت نمایش نشانک ها</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="458"/>
        <source>&amp;Bottom</source>
        <translation>&amp;پایین</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="459"/>
        <source>&amp;Top</source>
        <translation>&amp;بالا</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="460"/>
        <location filename="../mainwindow.cpp" line="496"/>
        <source>&amp;Right</source>
        <translation>&amp;راست</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <location filename="../mainwindow.cpp" line="497"/>
        <source>&amp;Left</source>
        <translation>&amp;چپ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>&amp;Tabs Layout</source>
        <translation>&amp;جایگاه زبانه ها</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="495"/>
        <source>&amp;None</source>
        <translation>&amp;هیچکدام</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="513"/>
        <source>S&amp;crollbar Layout</source>
        <translation>&amp;نمایش نوارپیمایش</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>&amp;BlockCursor</source>
        <translation>مکان نما &amp;مکعب</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="527"/>
        <source>&amp;UnderlineCursor</source>
        <translation>مکان نما &amp;زیرخط</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="528"/>
        <source>&amp;IBeamCursor</source>
        <translation>مکان نما &amp;خط عمودی</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="545"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>&amp;شکل مکان نما صفحه کلید</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="633"/>
        <source>A process is running.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>Exit QTerminal</source>
        <translation>خروج از کیو ترمینال</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>Are you sure you want to exit?</source>
        <translation>مطمئن هسنید می خواهید خارج شوید؟</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="689"/>
        <source>About</source>
        <translation>درباره</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="691"/>
        <source>A lightweight and powerful multiplatform terminal emulator</source>
        <translation>یک شبیه ساز ترمینال چندسکویی قدرتمند و سبک</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="693"/>
        <source>Copyright (C) </source>
        <translation>کپی‌رایت(C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="693"/>
        <source>2013-2025</source>
        <translation>۱۳۹۱-۱۴۰۱</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="695"/>
        <source>LXQt Project</source>
        <translation>پروژه LXQt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="697"/>
        <source>Development: </source>
        <translation>توسعه: </translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>تنظیمات ترمینال</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="21"/>
        <source>Appearance</source>
        <translation>نمایش</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="38"/>
        <location filename="../forms/propertiesdialog.ui" line="729"/>
        <source>Behavior</source>
        <translation>عملکرد</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="47"/>
        <source>Shortcuts</source>
        <translation>میانبرها</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="56"/>
        <source>Dropdown</source>
        <translation>کشویی</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="65"/>
        <source>Bookmarks</source>
        <translation>نشانک ها</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="556"/>
        <source>Hide tab bar with only one tab</source>
        <translation>مخفی کردن نوار زبانه ها وقتی که فقط یک زبانه وجود دارد</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="181"/>
        <source>Color scheme</source>
        <translation>رنگبندی</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="207"/>
        <source>Scrollbar position</source>
        <translation>موقعیت نوار لغزان</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="370"/>
        <source>Start with preset:</source>
        <translation>شروع به کار با طرح پیشفرض:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="287"/>
        <source>Terminal transparency</source>
        <translation>شفافیت ترمینال</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="381"/>
        <source>None (single terminal)</source>
        <translation>هیچکدام (تک ترمینال)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="386"/>
        <source>2 terminals horizontally</source>
        <translation>۲ ترمینال افقی</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="391"/>
        <source>2 terminals vertically</source>
        <translation>۲ ترمینال عمودی</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="396"/>
        <source>4 terminals</source>
        <translation>۴ ترمینال</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="297"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="135"/>
        <source>Font</source>
        <translation>فونت</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="171"/>
        <source>&amp;Change...</source>
        <translation>&amp;تغییر...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="220"/>
        <source>Tabs position</source>
        <translation>موقعیت زبانه ها</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="194"/>
        <source>Widget style</source>
        <translation>فرم پنجره برنامه</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="512"/>
        <source>Show the menu bar</source>
        <translation>نمایش نوار منو</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="233"/>
        <source>Cursor shape</source>
        <translation>شکل مکان نما</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="270"/>
        <source>Enable bi-directional text support</source>
        <translation>فعال سازی پشتیبانی از متن دوجهته</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="313"/>
        <source>Background image:</source>
        <translation>تصویر پس زمینه:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="325"/>
        <source>Select</source>
        <translation>انتخاب</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="263"/>
        <source>Show terminal size on resize</source>
        <translation>ابعاد ترمینال را در هنگام تغییر اندازه نمایش بده</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="563"/>
        <source>Fixed tab width:</source>
        <translation>عرض زبانه ثابت:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="414"/>
        <location filename="../forms/propertiesdialog.ui" line="573"/>
        <source>px</source>
        <translation>پیکسل</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="536"/>
        <source>Show close button on each tab</source>
        <translation>نمایش دکمه بستن برای هر زبانه</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="404"/>
        <source>Terminal margin</source>
        <translation>اندازه لبه ترمینال</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="280"/>
        <source>Use box drawing characters contained in the font</source>
        <translation>استفاده از جعبه های طراحی داخل فونت</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="519"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation>شتاب دهنده ها توسط Alt فعال می شوند و می توانند در ترمینال تداخل ایجاد کنند.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="522"/>
        <source>No menu bar accelerator</source>
        <translation>شتاب دهنده های نوار منو استفاده نشوند</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="922"/>
        <source>Emulation</source>
        <translation>شبیه سازی</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="762"/>
        <source>Action after paste</source>
        <translation>عملکرد بعد از چسباندن</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="828"/>
        <source>Confirm multiline paste</source>
        <translation>تایید قبل از چسباندن چند خطی</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="835"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>در زمان چسباندن کرکتر خط جدید را حذف کن</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="849"/>
        <source>Open new terminals in current working directory</source>
        <translation>باز کردن ترمینال جدید در پوشه جاری</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="590"/>
        <source>Save Size when closing</source>
        <translation>ذخیره اندازه در هنگام خروج</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="583"/>
        <source>Save Position when closing</source>
        <translation>ذخیره موقعیت در هنگام خروج</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="755"/>
        <source>Unlimited history</source>
        <translation>تاریخچه بدون محدودیت</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="735"/>
        <source>History size (in lines)</source>
        <translation>اندازه تاریخچه (بر اساس تعداد خط)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="873"/>
        <source>Default $TERM</source>
        <translation>$TERM پیشفرض</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="609"/>
        <source>Start with this size:</source>
        <translation>شروع به کار با این اندازه:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="334"/>
        <source>Background mode:</source>
        <translation>مدل پس زمینه:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="342"/>
        <source>None</source>
        <translation>هیچکدام</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="347"/>
        <source>Stretch</source>
        <translation>کشیده شده</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="352"/>
        <source>Zoom</source>
        <translation>بزرگنمایی</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="357"/>
        <source>Fit</source>
        <translation>به اندازه</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="362"/>
        <source>Center</source>
        <translation>وسط</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="277"/>
        <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
        <translation>نعیین کردن اینکه از جعبه طراحی باید توسط کیو ترمینال زسم شوند یا به عهده فونت اصلی گذاشته شود.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="253"/>
        <source>Toggles usage of bold font face for rendering intense colors</source>
        <translation>انتخاب وضعیت استفاده ازفونت پررنگ برای نمایش رنگ های تند</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="256"/>
        <source>Use bold font face for intense colors</source>
        <translation>استفاده از فونت پررنگ برای رنگ های تند</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="529"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;کناره های پنجره پنهان شود</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="931"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;انتخاب عملکرد برای شبیه سازی. توجه داشته باشید که این قابلیت لزوما با سیستم‌عامل شما هم‌خوانی ندارد.&lt;/p&gt;&lt;p&gt;اگر مطمئن نیستید از شبیه‌ساز &lt;span style=&quot; font-weight:600;&quot;&gt;پیشفرض&lt;/span&gt; استفاده کنید.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="909"/>
        <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
        <translation>این دستور با پارامتر حاوی نام یک فایل موقت که حاوی تاریخچه پیمایش می باشد اجرا می شود</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="912"/>
        <source>Handle history command</source>
        <translation>مدیریت تاریخچه دستورات</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="616"/>
        <location filename="../forms/propertiesdialog.ui" line="630"/>
        <source> px</source>
        <translation> پیکسل</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="637"/>
        <source>Get current size</source>
        <translation>اندازه فعلی را بگیر</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="859"/>
        <source>Open new tab to the right of the active tab</source>
        <translation>زبانه جدید را در سمت راست ونجره فغلی باز کن</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="856"/>
        <source>If unchecked the new tab will be opened as the rightmost tab</source>
        <translation>اگر انتخاب نشود، زبانه جدید در منتها الیه سمت راست باز می شود</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="546"/>
        <source>Close tab on middle-click</source>
        <translation>با کلیک وسط زبانه را ببند</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="821"/>
        <source>Forcefully disable bracketed paste mode</source>
        <translation>حالت چسباندن براکت را به زور غیرفعال کنید</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="775"/>
        <source>Word selection characters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="30"/>
        <source>Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="246"/>
        <source>Blinking cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="421"/>
        <source>Current Terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="427"/>
        <source>Draw a border</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="434"/>
        <source>Set the current terminal on mouseover</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="441"/>
        <source>Change window title based on the terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="448"/>
        <source>Change window icon based on the terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="597"/>
        <source>Save State when closing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="782"/>
        <source>When selecting text by word, consider these characters as part of words in addition to alphanumeric characters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="785"/>
        <source>:@-./_~</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="792"/>
        <source>Mouse cursor hiding delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="799"/>
        <source>No hiding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="802"/>
        <source> sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="818"/>
        <source>Bracketed paste mode is useful for pasting multiline strings.</source>
        <translation>حالت چسباندن براکت برای چسباندن رشته های چند خطی مفید است.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="842"/>
        <source>Prompt on closing with a running process</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="866"/>
        <source>Audible bell</source>
        <translation>زنگ صدا دار</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="955"/>
        <source>To edit a Shortcut:
1. Double-click its Key
2. Press the desired combination and release it
3. Click on a Shortcut or press Enter

To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</source>
        <translation>برای ویرایش یک میانبر:
۱. بر روی کلید آن دوبار کلیک کنید
۲. ترکیب مورد نظر را فشار داده و رها کنید
۲. بر روی یک میانبر کلیک کنید یا Enter را فشار دهید

برای حذف / غیرفعال کردن یک میانبر ، در نقطه 2 فقط یک اصلاح کننده (مانند Shift) را فشار دهید</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="985"/>
        <source>Shortcut</source>
        <translation>میانبر</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="990"/>
        <source>Key</source>
        <translation>کلید</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1002"/>
        <source>Show on start</source>
        <translation>نمایش در هنگام شروع به کار</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1009"/>
        <source>A lock button is shown on horizontal tab bar</source>
        <translation>یک دکمه قفل روی میله تب افقی نمایش داده می‌شود</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1012"/>
        <source>Keep window open when it loses focus</source>
        <translation>هنگام از دست دادن فوکوس پنجره را باز نگه دار</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1019"/>
        <source>Size</source>
        <translation>اندازه</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1030"/>
        <source>Height</source>
        <translation>ارتفاع</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1040"/>
        <location filename="../forms/propertiesdialog.ui" line="1063"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1053"/>
        <source>Width</source>
        <translation>عرض</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1083"/>
        <source>Shortcut:</source>
        <translation>میانبر:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1092"/>
        <source>Note: On Wayland, the shortcut has to be added in the compositor settings for &apos;qterminal -d&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1160"/>
        <source>Edit bookmark file contents</source>
        <translation>ویرایش محتویات فایل میانبر</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1119"/>
        <source>Enable bookmarks</source>
        <translation>نمایش نشانک ها</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1128"/>
        <source>Bookmark file</source>
        <translation>فایل نشانک ها</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1141"/>
        <source>Find...</source>
        <translation>جستجو...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1150"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>می توانید مکان فایل بوک مارک های خود را مشخص کنید. این امکان به اشتراک گذاری نشانک را به راحتی با ابزارهایی ماننددراپ باکس را فراهم می کند.</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="167"/>
        <source>No scrollbar</source>
        <translation>بدون نوار های لغزان</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="167"/>
        <location filename="../propertiesdialog.cpp" line="173"/>
        <source>Left</source>
        <translation>چپ</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="167"/>
        <location filename="../propertiesdialog.cpp" line="173"/>
        <source>Right</source>
        <translation>راست</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="173"/>
        <source>Top</source>
        <translation>بالا</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="173"/>
        <source>Bottom</source>
        <translation>پایین</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="186"/>
        <source>BlockCursor</source>
        <translation>مکان نما مکعبی</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="186"/>
        <source>UnderlineCursor</source>
        <translation>مکان نمای زیرخط</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="186"/>
        <source>IBeamCursor</source>
        <translation>مکان نما خط عمودی</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="208"/>
        <source>No move</source>
        <translation>بی حرکت</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="208"/>
        <source>Scrolling to top</source>
        <translation>لغزش به بالا</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="208"/>
        <source>Scrolling to bottom</source>
        <translation>لغزش به پایین</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="289"/>
        <source>Examples</source>
        <translation>نمونه ها</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="456"/>
        <source>Images (*.bmp *.jpg *.png *.svg *.xpm)</source>
        <translation>تصاویر (*.bmp *.jpg *.png *.svg *.xpm)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="558"/>
        <source>Open bookmarks file</source>
        <translation>فایل نشانک ها را باز کن</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="560"/>
        <source>XML files (*.xml)</source>
        <translation>فایل های xml) XML.*)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="561"/>
        <source>All files (*)</source>
        <translation>تمام فایل ها (*)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="660"/>
        <location filename="../propertiesdialog.cpp" line="664"/>
        <source>Question</source>
        <translation>سؤال</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="660"/>
        <source>Do you want to overwrite this bookmarks file?</source>
        <translation>آیا می خواهید این فایل نشانک ها را بازنویسی کنید؟</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="664"/>
        <source>The name of bookmarks file does not end with &apos;.xml&apos;.
Are you sure that you want to overwrite it?</source>
        <translation>نام فایل نشانک ها با &apos;xml.&apos; تمام نشده است.
آیا مطمئن هستید که میخواهید آن را بازنویسی کنید؟</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="672"/>
        <source>Warning</source>
        <translation>اخطار</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="672"/>
        <source>Cannot write bookmarks to this file:</source>
        <translation>نمی شود بوک‌مارک ها را در این فایل ذخیره کرد:</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="225"/>
        <location filename="../propertiesdialog.cpp" line="342"/>
        <source>System Default</source>
        <translation>پیش‌فرض های سیستم</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="455"/>
        <source>Choose a background image</source>
        <translation>انتخاب یک تصویر پس زمینه</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="114"/>
        <source>Synchronized Bookmarks</source>
        <translation>نشانک های همگام سازی شده</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="85"/>
        <location filename="../tabwidget.cpp" line="254"/>
        <source>Shell No. %1</source>
        <translation>پوسته ی شماره %1</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="150"/>
        <source>Close Subterminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="150"/>
        <source>Are you sure you want to close this subterminal?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="222"/>
        <source>Tab name</source>
        <translation>عنوان زبانه</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="223"/>
        <source>New tab name:</source>
        <translation>عنوان جدید برای زیانه:</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="243"/>
        <source>Select new tab title color</source>
        <translation>انتخاب رنگ جدید برای عنوان زیانه</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="272"/>
        <source>Close session</source>
        <translation>بستن جلسه کاری</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="274"/>
        <source>Change title color</source>
        <translation>تغییر رنگ عنوان</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="356"/>
        <source>Close tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="356"/>
        <source>Are you sure you want to close this tab?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="77"/>
        <source>Load Session</source>
        <translation>فراخوانی جلسه کاری</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="78"/>
        <source>List of saved sessions:</source>
        <translation>لیست جلسه کاری های ذخیره شده:</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>پنجره اصلی</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="62"/>
        <source>&amp;Session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="70"/>
        <source>&amp;Actions</source>
        <translation>&amp;عملیات</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="75"/>
        <source>&amp;Help</source>
        <translation>&amp;دستیار</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="82"/>
        <source>&amp;View</source>
        <translation>&amp;نمایش</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="87"/>
        <source>&amp;Edit</source>
        <translation>&amp;ویرایش</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="103"/>
        <source>&amp;About...</source>
        <translation>&amp;درباره ...</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="108"/>
        <source>About &amp;Qt...</source>
        <translation>درباره &amp;Qt...</translation>
    </message>
</context>
</TS>
